/**
 * 
 */
package org.gcube.portlets.user.td.gwtservice.shared;


/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class Constants {

	public final static String VERSION = "2.0.0";		
	public final static String DEFAULT_USER = "giancarlo.panichi";
	public final static String DEFAULT_SCOPE = "/gcube/devsec";

	public static final String PARAMETER_ENCODING = "encoding";
	public static final String PARAMETER_HASHEADER = "hasHeader";
	public static final String PARAMETER_SEPARATOR = "separator";
	public static final String PARAMETER_COLUMNS = "columns";
	public static final String PARAMETER_URL = "url";
	
	public static final String PARAMETER_REGISTRYBASEURL ="registryBaseUrl";
	public static final String PARAMETER_AGENCY ="agency";
	public static final String PARAMETER_ID ="id";
	public static final String PARAMETER_VERSION ="version";
	
	public static final String PARAMETER_DATA_TYPE="dataType";
	public static final String PARAMETER_TARGET_DATA_TYPE="targetDataType";
	
	public static final String PARAMETER_EXPRESSION="expression";
	
	public static final String PARAMETER_TABLE_TYPE="tableType";

}
